globals [
  farmers-caught
  wells-closed
  water-picked
  dried-water
  dissatisfaction
  incomechanges
  ]
breed [farmers farmer]
breed [polices police]
patches-own [
  picked
  ]

polices-own[
  steps
  mystation
  polices-in-radius-2

  ]
farmers-own [
times-found
  my-extra-water-seeking-capacity
  my-extra-water-need
 neighbors-in-need
  well?
  myland
  fined?
  polices-in-radius-2
   ]

to setup
  clear-all
;; create number of patches for stationing police-water,
  ask n-of water-police-station patches [set pcolor 106 ]
  ask n-of water-police-station patches with [pcolor = 106][sprout 1 [set breed polices set shape "police" set steps 0 set mystation patch-here]]
  ;; create number of patches as the water sources
  ask n-of water-source patches with [pcolor != 106]  [set pcolor 87]
  ;; create number of patches as farmland with red, represents high water demand crop, and green, represents low water demand crop
  ask n-of number-of-farmlands patches with [(pcolor != 106  and pcolor != 87)]
  [ ifelse random-float 1 < 0.1 [set pcolor green][set pcolor red]
  ;;create turtles on each farmland not moving until they move-seeking-extra-water
    sprout-farmers 1 [ set color yellow  set well? false set fined? false set myland patch-here]
  ]
  reset-ticks
end

to go
 ;; farmer decides to move to get extra water based on its own needs and capacity as well as
  ;; its neighbors' capacities and needs
  ;; if farmer has no capacity to seek extra water but need extra water,it may dig a well if
  ;; at least more than one of its neighbors is in the same situation,
  ;; otherwise farmer either leaves the farmland uncultivated or change the crop
  ask farmers with [well? = false][
   set my-extra-water-seeking-capacity random-float 100
   set my-extra-water-need one-of [0 1]]

  ask farmers with [my-extra-water-need = 1 and (my-extra-water-seeking-capacity < extra-water-seeking-capacity)][
   let neighborF farmers-on neighbors
   set neighbors-in-need count neighborF with
   [ (my-extra-water-need = 1 ) and (my-extra-water-seeking-capacity < extra-water-seeking-capacity)]

   ifelse neighbors-in-need > 1 [
     set well? true set my-extra-water-need 0
     ask farmers-on neighbors [set well? true set my-extra-water-need 0 ]
     ][
     ifelse random-float 1 < 0.05 [ask patch-here [set pcolor grey] set dissatisfaction dissatisfaction + 1 set incomechanges incomechanges - 4500 die]
     [ ask patch-here [set pcolor green set incomechanges incomechanges - 1500 ] ]
     ]
    ask farmers with [well?][ask patch-here [set pcolor red]]]


   ;;farmer seeks surface water (river) (sub-model)

   ;;the condition for seeking extra water and moving to get extra water is set as farmer is in need and it has a capacity to seek extra water.
   ;; if the punishment law is applied farmer checkes its record of being cauth by police. Here it is set to less than 5.
   ;; if the punishment law is not applied the last part of the condition, which is linked with "and", has to be comment out

   ask farmers with [my-extra-water-need = 1 and (my-extra-water-seeking-capacity > extra-water-seeking-capacity) and (times-found < 5 )
     ]
   [
     let neighborFar farmers-on neighbors
     if (count neighborFar = 0) or ((count neighbors with [pcolor = red]) / (count neighborFar) > 0.5)
     [if (count patches with [pcolor = 87] > 0 )[ move-to one-of patches with [pcolor = 87]]]


   ]

   ;;police-water catches farmer (sub-model)

   ;;police-water moves randomly around and gets back to the station
   ;;police-water sees farmer-picking-water and farmers-with-well in radius 2, record the farmer caught as being fined
   ;;farmer who is caught by police-water goes back to its farmland and changes its crop to low water demand crop
   ;;the wells of farmer-with-wells who is caught by police-water is filled if it is seen by police-water
  ;; farmer-with-wells, who is caught by police-water either leaves the land uncultivated (grey) or cultivate the farmland with low water demand crop
   ask polices [
     if steps = 0 [ rt random 360 ]
     if steps = 10 [face mystation]
     fd 1
     set steps steps + 1
     let water-i-can-see patches with [pcolor = 87] in-radius 2
     let farmer-picking-water farmers-on water-i-can-see
     if count farmer-picking-water > 0 [
       ask farmer-picking-water [
         move-to myland
         ask patch-here [set pcolor green]
         set farmers-caught farmers-caught + 1
         set times-found times-found + 1
         set dissatisfaction dissatisfaction + 1
         set incomechanges incomechanges - 1500
         set fined? true
       ]
       ]
     let nearby-farmers farmers in-radius 2
     let farmer-with-well nearby-farmers with [well?]
     if count farmer-with-well > 0[
       ask farmer-with-well [
         ifelse random-float 1 < 0.05 [ask patch-here [set pcolor grey]  set dissatisfaction
           dissatisfaction + 1 set incomechanges incomechanges - 4500 die]
       [ ask patch-here [set pcolor green] set well? false
        set dissatisfaction dissatisfaction + 1
        set incomechanges incomechanges - 4500
         ]

         set wells-closed wells-closed + 1
       ]

     ]
     if patch-here = mystation [set steps 0]
   ]

   ;;farmer gets water (sub-model)

   ask farmers-on patches with [pcolor = 87] [ask patch-here [set picked picked + 1] move-to myland ask patch-here [set pcolor red]
     set water-picked water-picked + 1
     ]

   ;;water may dry and return (sub-model)

   ask patches with [pcolor = 87][
     if picked > 100 [set pcolor brown set dried-water dried-water + 1]]

   ask patches  with [pcolor = brown][
     if random-float 1 < 0.05 [set pcolor 87 set picked 0]]

   ;;increase/decrease number of police-water based on different strategic targets (sub-model)

   ;;ifelse count patches with [pcolor = red] = 0
   ;;ifelse (count patches with [pcolor = red] * 4) < (count patches with [pcolor = green] + (count patches with [pcolor = grey]))
   ifelse (count patches with [pcolor = red] * 6) < (count patches with [pcolor = green]  + ( count patches with [pcolor = grey] * 4.5) / 2 )
   [if count polices > 0 [ask one-of polices [die]]]
   [ask one-of patches with [pcolor = 106][sprout 1 [set breed polices set shape "police" set steps 0 set mystation patch-here]]]



   ;;new people come in- New comers (sub-model)

   ask patches with [pcolor = grey]
   [if random-float 1 < 0.1
     [sprout-farmers 1 [ set color yellow set well? false set myland patch-here]
      ifelse random-float 1 < 0.2 [set pcolor green set incomechanges incomechanges + 1500]
       [set pcolor red set incomechanges incomechanges + 4500]
     ]

   ]

   tick
end
@#$#@#$#@
GRAPHICS-WINDOW
241
10
581
371
16
16
10.0
1
8
1
1
1
0
1
1
1
-16
16
-16
16
0
0
1
ticks
20.0

BUTTON
6
10
72
43
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
78
10
141
43
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
3
59
186
92
water-police-station
water-police-station
0
100
69
1
1
NIL
HORIZONTAL

SLIDER
4
112
185
145
extra-water-seeking-capacity
extra-water-seeking-capacity
0
100
18
1
1
NIL
HORIZONTAL

SLIDER
6
156
185
189
number-of-farmlands
number-of-farmlands
0
1000
116
1
1
NIL
HORIZONTAL

BUTTON
145
11
210
47
go-once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
911
21
1015
66
NIL
farmers-caught
17
1
11

MONITOR
738
19
820
64
NIL
wells-closed
17
1
11

MONITOR
652
17
735
62
NIL
water-picked
17
1
11

PLOT
893
70
1254
329
crop changes
time
number of farms
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"LWD" 1.0 0 -13840069 true "" "plot count patches with [pcolor = green]"
"HWD" 1.0 0 -2674135 true "" "plot count patches with [pcolor = red ]"
"UC" 1.0 0 -7500403 true "" "plot count patches with [pcolor = grey]"

MONITOR
823
20
902
65
NIL
dried-water
17
1
11

SLIDER
3
198
187
231
water-source
water-source
0
50
7
1
1
NIL
HORIZONTAL

MONITOR
1002
335
1062
380
polices
count  polices
17
1
11

PLOT
673
240
873
390
dissatisfaction
time
number
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot dissatisfaction"

PLOT
976
383
1176
533
police-farmers
time
number
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"P" 1.0 0 -13345367 true "" "plot count polices"
"F" 1.0 0 -6459832 true "" "plot count farmers"

PLOT
683
397
883
547
incomechanges
time
$1000
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot incomechanges / 1000"

MONITOR
1063
336
1125
381
farmers
count farmers
17
1
11

PLOT
669
71
869
221
dried-water
NIL
NIL
0.0
100.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot dried-water"

@#$#@#$#@
## WHAT IS IT?

Command-And-Control is a model to understand how limiting farmers' access to water and controling it by water-police could force farmers to change their crops from high-water-demand crops to low-water-demand crops. This model is inspired by and based on the policy of Urmia Lake Restoration Program (ULRP) in Northwestern  Iran. Urmia Lake  has gone through a drought process and ULRP intends to restore the lake artificially through diverse projects. One of the projcets is to esablish water-police to monitore and control water consumption.

The name of the program, Command-And-Control, which has been a dominant approach in natural resource management, is borrowed from C.S. Holling and Gary Meffe (1995). They identify the command-and control as a “linear” “cause and effect” “problem solving” approach, which assumes there is a controllable solution to a well-defined problem. Applying command-and-control approach in a social-ecological complex system of natural resources not only does not produce the expected outcomes, but also, different issues emerge as the consequences of implementing the command-and-control approach. In this model, the linear approach of the ULRP command-and-control is built to observe how it works within the social-ecological complex system. In ULRP, domination of HWD crops is considered as the cause of the lake’s draught problem. Limiting farmers’ access to water at the amount that LWD crops need is the commanding solution. As it is perceived that farmers would seek extra water through surface water sources or digging wells to increase their access to extra water to cultivate HWD crops, the water-police establishment is introduced to control farmers’ access to extra water. The model follows the heuristic based rule-action of the mental model inductive procedure (Holland,1986) for natural resources when human agents reasoning their actions (Jones et al., 2011). The agents’ decision follow the rules that are extracted intuitively from the empirical information.

In 2017, this model is programed by Farzaneh Davari, a Ph.D. candidate of Computational Social Science in George Mason University.


## HOW IT WORKS
In this model, in the beginning of the cultivating season, each farmland is allocated to the specific amount of water, which is sufficient for the low-water-demand (LWD) crops. However, farmers’ decisions on crop pattern do not necessarily follow the allocated amount of water to the farmlands. Farmers’ decisions for cultivating crops are affected by their perceptions of their status, their neighbors’ status, the availability of water-sources, as well as their interactions with the water-polices. A farmer’s crop type decision follows a decision-making path. A farmer faces three types of final decision: cultivating the land with high-water-demand crop (HWD) or low-water-demand crop (LWD) or leaving the land uncultivated. The sequential process that a farmer follows for deciding is as follows:

The first thing a farmer agent checks is its need for extra water. If it doesn’t need extra water, it decides to cultivate low-water-demand (LWD) crop. If the farmer agent needs extra water, it checks if it has the capacity to seek extra water. If it does, the farmer also checks its neighbors’ status for the security reason.  If more than half of the farmer agent’s neighbors cultivate HWD crop, the farmer decides to move to the water sources to take extra water. However, if the legal punishment law is in effect, the farmer agent also checks its records of being fined before deciding to move for seeking extra water. If the farmer agent is fined less than 5 times the farmer moves for taking extra water.  If the farmer who is moving to take extra water is not in the vision of the water-polices, who are moving around, the farmer agent picks water and goes back to its farmland and cultivates HWD crop. If the farmer who is seeking extra water is caught by the water-police it goes back to its land and its status changes to the farmer who is in need but has no capacity of seeking extra water.

Meanwhile, if the farmer agent has no capacity to seek extra water but is in need of extra water, it checks its neighbors for the same situation. If the farmer agent has at least one neighbor in the same situation, the farmer decides to dig a well and cultivate HWD crop if the water-police cannot see the farmer digging the well. If the water-police catches the farmer digging a well, the well will be filled up and the farmer will be returned to its farmland to decide to either cultivate its land with the LWD crop or leave it uncultivated.

There are three patches and three agents. One of the patches is water-police-station, which is randomly distributed wihtin the global number of the water-police-station and water-police agent is sprout randomly. The number of water-police increases or decreases based on the strategy that is identified in the sub-model section of increase or decrease water-police. Several strategies are programed that each time one of them can be run and the result can be compared. For example, within certain strategic target, if the number of farmlands with high-water-demand crop is multiplied by 6 is less than average number of farmlands with low-water-demand crops and the number of uncultivated farmlands multiply by 4.5, one water-police will be added to the exisitng water-police, otherwise the number of police decreases. The second patch is water-source, which is randomly distributed within the global number of the water-source and act as the water-source agent. A threshold is identified for water-source and if it crosses the threshold it dries but there is a random chance to be renewed. The third patch is farmland which is randomly distributed within the global number-of- farmlands, and assigned to two types of LWD or HWD crops.the farmer agents are randomly sprout and every farmer randomly receives my-extra-water-seeking-capacity within the range of extra-water-seeking-capacity. Likewise, each farmer randomly receives a binary value of my-extra-water-need.

Besides the main plot for crop changes, there is a plot showing the changes in number of farmers and water-police. The number of water-police is calculated simply by adding or subtracting one unit when the model automatically deploys or withdraws a water-police. The changes in the number of farmer agents is based on the number of farmers who leave their lands uncultivated or the uncultivated lands return to the farmlands by the newcomers. When a farmer agent leaves the farmland uncultivated the number of farmer agents decreases one unit and when a newcomer decides on farming an uncultivated land the number of farmers increases one unit.

Besides the main output of the crop changes, the model's outputs, which are the cumulative data at the system level, include the numbers of picked-up water, the wells-closed, the dried-water-sources, the farmers-caught, and the dissatisfaction as well as the gross income values. In the coding section the calculation can be found.

## HOW TO USE IT

Set four sliders in the interface at the different settings and press setup botton. look at the world carefully and see how three patches and water-police and farmlands are set.  Then press go-once and see what happens in the world. At the same time monitor the plots of crop changes as well as the other plots and the moniotrs. Continue to explore how crop patterns change and at the same time how the other outputs change. Under certain conditions, it takes a long time when the crop pattern becomes quite stablized. So, use button go instead of go-once and leave the model runs for hours and find out the changes.

## THINGS TO NOTICE
Change the sliders and observe the world carefully and find out how water-polices are moving, how farmlands changes, and when the water sources become dried/or return to water-source. Moreover, as the crop patterns changing can be monitored in the plot try to find out when the high-water-demand crop crosses the low-water demand crop and when the new crop pattern is stablized. Still, it takes a long time, some times more than 5000 time steps, to ensre that the crop pattern won't change drastically anymore.

## THINGS TO TRY

Beside the sliders that can be adjusted at different numbers, there are possibilities to change the strategic targets to change the crop pattern, which can be found under the increse/decrease water-police sub-model. Moreover, there are several random numbers and thresholds that can be changed in order to find out their effects on the results of the model.

## EXTENDING THE MODEL

Two outputs of dissatisfaction and income-changes are not in main focus of the programing and it is suitable to program them as sub-models because they could  follow their own rules and affect farmers' as well as law enforcements' decisions.


## CREDITS AND REFERENCES
Holland, John H., Keith J. Holyoak, Richard E. Nisbett, and Paul R. Thagard (1986). Introduction: Processes of Inference, Learning, and Discovery. Cambridge, Mass: MIT Press.

Holling, C. and Meffe, G. (1995). Command and Control and the Pathology of Natural Resource Management. Conservation Biology, 10(2), pp.328-337

Jones, N., Ross, H., Lynam, T., Perez, P. and Leitch, A. (2011). Mental Models: An Interdisciplinary Synthesis of Theory and Methods. Ecology and Society, 16(1).

Urmia Lake Restoration Program, Sharif University of Technology, (2015) Urmia Lake Restoration Program: Brief Report and Project Outline

Wilensky, U. (1999). NetLogo. http://ccl.northwestern.edu/netlogo/. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

faramer
false
0
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -1 true false 60 195 90 210 114 154 120 195 180 195 187 157 210 210 240 195 195 90 165 90 150 105 150 150 135 90 105 90
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -13345367 true false 120 90 120 180 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 180 90 172 89 165 135 135 135 127 90
Polygon -6459832 true false 116 4 113 21 71 33 71 40 109 48 117 34 144 27 180 26 188 36 224 23 222 14 178 16 167 0
Line -16777216 false 225 90 270 90
Line -16777216 false 225 15 225 90
Line -16777216 false 270 15 270 90
Line -16777216 false 247 15 247 90
Rectangle -6459832 true false 240 90 255 300

farmer
false
0
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -1 true false 60 195 90 210 114 154 120 195 180 195 187 157 210 210 240 195 195 90 165 90 150 105 150 150 135 90 105 90
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -13345367 true false 120 90 120 180 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 180 90 172 89 165 135 135 135 127 90
Polygon -6459832 true false 116 4 113 21 71 33 71 40 109 48 117 34 144 27 180 26 188 36 224 23 222 14 178 16 167 0
Line -16777216 false 225 90 270 90
Line -16777216 false 225 15 225 90
Line -16777216 false 270 15 270 90
Line -16777216 false 247 15 247 90
Rectangle -6459832 true false 240 90 255 300

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

person farmer
false
0
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -1 true false 60 195 90 210 114 154 120 195 180 195 187 157 210 210 240 195 195 90 165 90 150 105 150 150 135 90 105 90
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -13345367 true false 120 90 120 180 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 180 90 172 89 165 135 135 135 127 90
Polygon -6459832 true false 116 4 113 21 71 33 71 40 109 48 117 34 144 27 180 26 188 36 224 23 222 14 178 16 167 0
Line -16777216 false 225 90 270 90
Line -16777216 false 225 15 225 90
Line -16777216 false 270 15 270 90
Line -16777216 false 247 15 247 90
Rectangle -6459832 true false 240 90 255 300

person soldier
false
0
Rectangle -7500403 true true 127 79 172 94
Polygon -10899396 true false 105 90 60 195 90 210 135 105
Polygon -10899396 true false 195 90 240 195 210 210 165 105
Circle -7500403 true true 110 5 80
Polygon -10899396 true false 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -6459832 true false 120 90 105 90 180 195 180 165
Line -6459832 false 109 105 139 105
Line -6459832 false 122 125 151 117
Line -6459832 false 137 143 159 134
Line -6459832 false 158 179 181 158
Line -6459832 false 146 160 169 146
Rectangle -6459832 true false 120 193 180 201
Polygon -6459832 true false 122 4 107 16 102 39 105 53 148 34 192 27 189 17 172 2 145 0
Polygon -16777216 true false 183 90 240 15 247 22 193 90
Rectangle -6459832 true false 114 187 128 208
Rectangle -6459832 true false 177 187 191 208

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

police
false
0
Rectangle -7500403 true true 127 79 172 94
Polygon -10899396 true false 105 90 60 195 90 210 135 105
Polygon -10899396 true false 195 90 240 195 210 210 165 105
Circle -7500403 true true 110 5 80
Polygon -10899396 true false 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -6459832 true false 120 90 105 90 180 195 180 165
Line -6459832 false 109 105 139 105
Line -6459832 false 122 125 151 117
Line -6459832 false 137 143 159 134
Line -6459832 false 158 179 181 158
Line -6459832 false 146 160 169 146
Rectangle -6459832 true false 120 193 180 201
Polygon -6459832 true false 122 4 107 16 102 39 105 53 148 34 192 27 189 17 172 2 145 0
Polygon -16777216 true false 183 90 240 15 247 22 193 90
Rectangle -6459832 true false 114 187 128 208
Rectangle -6459832 true false 177 187 191 208

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <exitCondition>ticks &gt;= 5000</exitCondition>
    <metric>count patches with [pcolor = green]</metric>
    <metric>count patches with [pcolor = red]</metric>
    <metric>count patches with [pcolor = grey]</metric>
    <metric>count patches with [pcolor = brown]</metric>
    <metric>wells-closed</metric>
    <metric>farmers-caught</metric>
    <metric>water-picked</metric>
    <metric>count polices</metric>
    <metric>count farmers</metric>
    <metric>dissatisfaction</metric>
    <metric>incomechanges</metric>
    <enumeratedValueSet variable="extra-water-seeking-capacity">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="police-water-station">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="water-source">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmlands">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="water-source">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extra-water-seeking-capacity">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="police-water">
      <value value="84"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmlands">
      <value value="771"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
